@@ -34,17 +34,19 @@ class Show(BaseShow):
                             metavar="<validation>",
                             type=str,
                             help="Show a specific validation.")
-        # Merge config and CLI args:
-        return self.base.set_argument_parser(parser)
+        return parser
 
     def take_action(self, parsed_args):
         """Take validation action"""
+        # Merge config and CLI args:
+        self.base.set_argument_parser(self, parsed_args)
         # Get parameters:
         validation_dir = parsed_args.validation_dir
         validation_name = parsed_args.validation_name
 
         v_actions = ValidationActions(validation_path=validation_dir)
-        data = v_actions.show_validations(validation_name)
+        data = v_actions.show_validations(
+                validation_name, validation_config=self.base.config)
 
         if data:
             return data.keys(), data.values()
@@ -61,15 +63,17 @@ class ShowGroup(BaseLister):
                             default=constants.ANSIBLE_VALIDATION_DIR,
                             help=("Path where the validation playbooks "
                                   "are located."))
-
-        # Merge config and CLI args:
-        return self.base.set_argument_parser(parser)
+        return parser
 
     def take_action(self, parsed_args):
         """Take validation action"""
+        # Merge config and CLI args:
+        self.base.set_argument_parser(self, parsed_args)
 
         v_actions = ValidationActions(parsed_args.validation_dir)
-        return v_actions.group_information(constants.VALIDATION_GROUPS_INFO)
+        return v_actions.group_information(
+                constants.VALIDATION_GROUPS_INFO,
+                validation_config=self.base.config)
 
 
 class ShowParameter(BaseShow):
@@ -147,10 +151,11 @@ class ShowParameter(BaseShow):
             help=("Print representation of the validation. "
                   "The choices of the output format is json,yaml. ")
         )
-        # Merge config and CLI args:
-        return self.base.set_argument_parser(parser)
+        return parser
 
     def take_action(self, parsed_args):
+        # Merge config and CLI args:
+        self.base.set_argument_parser(self, parsed_args)
 
         validation_dir = parsed_args.validation_dir
         v_actions = ValidationActions(validation_dir)
@@ -160,7 +165,8 @@ class ShowParameter(BaseShow):
             categories=parsed_args.category,
             products=parsed_args.product,
             output_format=parsed_args.format_output,
-            download_file=parsed_args.download)
+            download_file=parsed_args.download,
+            validation_config=self.base.config)
 
         if parsed_args.download:
             self.app.LOG.info(
